@@ -37,7 +37,7 @@ DO NOT EVER RUN THIS TEST AGAINST A PRODUCTION DATABASE.
 
 __copyright__ = 'Copyright (C) 2009, Purdue University'
 __license__ = 'BSD'
-__version__ = '1.04'
+__version__ = '1.05'
 
 
 import unittest
@@ -62,13 +62,15 @@ class TestNamedImport(unittest.TestCase):
     test_string = (
         u'single-option;\n'
         u'boolean-option yes;\n'
-        u'list-option { a; b; };\n')
+        u'list-option { a; b; };\n'
+        u'options {};\n')
 
     self.assertEqual(iscpy.Deserialize(iscpy.Serialize(test_string)),
+        u'single-option ;\n'
         u'boolean-option yes;\n'
+        u'options {  };\n'
         u'list-option { a;\n'
-        u'b; };\n'
-        u'single-option ;')
+        u'b; };')
 
   def testParse(self):
     self.assertEqual(iscpy.Explode(iscpy.ScrubComments(self.named_file)),
